@@ -23,6 +23,8 @@
 #include <Lum/Base/Path.h>
 #include <Lum/Base/String.h>
 
+#include <Lum/Def/Menu.h>
+
 #include <Lum/Dlg/About.h>
 #include <Lum/Dlg/Msg.h>
 
@@ -205,10 +207,12 @@ public:
       assert(false);
       break;
     case stateStoped:
+      value->GetClickAction()->Enable();
       value->SetAlarm(false);
       Lum::OS::display->RemoveTimer(timer);
       break;
     case stateRunning:
+      value->GetClickAction()->Disable();
       value->SetAlarm(false);
       lastMinutes=minutes->Get();
       lastSeconds=seconds->Get();
@@ -217,6 +221,7 @@ public:
       Lum::OS::display->AddTimer(0,100000,timer);
       break;
     case stateAlerting:
+      value->GetClickAction()->Disable();
       value->SetAlarm(true);
       minutes->Set(0);
       seconds->Set(0);
@@ -243,15 +248,19 @@ public:
                   ->Add(Lum::Button::Create(_(L"BUTTON_RESTART",L"_Restart"),restartAction,true,true))
                   ->Add(Lum::Button::Create(_(L"BUTTON_STOP",L"Sto_p"),stopAction,true,true))));
 
-    Lum::MenuDesc *menu=new Lum::MenuDesc();
+    Lum::Def::Menu *menu=Lum::Def::Menu::Create();
 
     menu
-      ->AddMenuItemSub(_ld(menuProject))
-        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
-    menu
-      ->AddMenuItemSub(_ld(menuHelp))
-        ->AddMenuItemAction(_ld(menuHelpHelp),NULL)
-        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
+      ->GroupProject()
+        ->ActionQuit(GetClosedAction())
+      ->End()
+      ->GroupEdit()
+        ->ActionSettings(value->GetClickAction())
+      ->End()
+      ->GroupHelp()
+        //->AddMenuItemAction(_ld(menuHelpHelp),NULL)
+        ->ActionAbout(aboutAction)
+      ->End();
 
     SetMenu(menu);
 
