@@ -83,13 +83,13 @@ Lum::Object* Selector::GetContent()
   slider->SetWidth(Lum::Base::Size::stdCharWidth,30);
   slider->SetFlex(true,false);
   slider->SetModel(minutes);
-  slider->SetScale(true);
+  slider->SetScale(false);
   label->AddLabel(_(L"LBL_MINUTES",L"Minutes"),slider);
 
   slider=new Lum::HSlider();
   slider->SetWidth(Lum::Base::Size::stdCharWidth,30);
   slider->SetFlex(true,false);
-  slider->SetScale(true);
+  slider->SetScale(false);
   slider->SetModel(seconds);
 
   label->AddLabel(_(L"LBL_SECONDS",L"Seconds"),slider);
